@@ -31,7 +31,7 @@
 #' par(mfrow=c(2,3))
 #' plot(tabs,which=1:6,new=FALSE)
 #' }
-plot.det.tables=function(x,which=5:6,angle=-45,density=20,col1="black",col2="blue", new=TRUE,...)
+plot.det.tables=function(x,which=1:6,angle=-45,density=20,col1="black",col2="blue", new=TRUE,...)
 {
 	plot_seen=function(x,col1,col2,...)
 	{
@@ -42,37 +42,37 @@ plot.det.tables=function(x,which=5:6,angle=-45,density=20,col1="black",col2="blu
 	    histline(missed+detected,breaks,lineonly=TRUE,col=col1,...)
 	}	
 	breaks=x$breaks
-	if(is.element(1,which)) 
+	if(is.element(1,which)&!is.null(x$Observer1)) 
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		plot_seen(x$Observer1,col1,col2,...)
 		legend("topright",legend=c("Detected by either observer","Detected by observer 1"),lty=1,lwd=3,col=c(col1,col2))
 	}
-	if(is.element(2,which)) 
+	if(is.element(2,which)&!is.null(x$Observer2)) 
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		plot_seen(x$Observer2,col1,col2,...)
 		legend("topright",legend=c("Detected by either observer","Detected by observer 2"),lty=1,lwd=3,col=c(col1,col2))
 	}
-	if(is.element(3,which)) 
+	if(is.element(3,which)&!is.null(x$Duplicates)) 
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		histline(x$Duplicates,breaks=breaks,lineonly=FALSE,xlab="Distance",ylab="Frequency",fill=TRUE,angle=angle,density=density,col=col1,...)
 		legend("topright",legend=c("Seen by both observers"),lty=1,lwd=3,col=c(col1))
 	}
-	if(is.element(4,which)) 
+	if(is.element(4,which)&!is.null(x$Pooled))
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		histline(x$Pooled,breaks=breaks,lineonly=FALSE,xlab="Distance",ylab="Frequency",fill=TRUE,angle=angle,density=density,col=col1,...)
 		legend("topright",legend=c("Seen by either observer"),lty=1,lwd=3,col=c(col1))
 	}
-	if(is.element(5,which)) 
+	if(is.element(5,which)&!is.null(x$Obs1_2)) 
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		plot_seen(x$Obs1_2,col1,col2,...)
 		legend("topright",legend=c("Detected by observer 2","Detected by observer 1 | 2"),lty=1,lwd=3,col=c(col1,col2))
 	}
-	if(is.element(6,which)) 
+	if(is.element(6,which)&!is.null(x$Obs2_1)) 
 	{
 		if(new& .Platform$GUI=="Rgui")dev.new()
 		plot_seen(x$Obs2_1,col1,col2,...)
