@@ -5,80 +5,28 @@
 #' histograms of the distances (for unconditional detection functions) or
 #' proportion of observations detected within distance intervals (for
 #' conditional detection functions) to compare visually the fitted model and
-#' data.  The structure of the histogram can be controlled by the user-defined
+#' data.  
+#' 
+#' The structure of the histogram can be controlled by the user-defined
 #' arguments \code{nc} or \code{breaks}.  The observation specific detection
 #' probabilities along with the line representing the fitted average detection
 #' probability.
 #' 
-#' In earlier versions of this package the plot routines other than
-#' \code{plot.ds} (\code{plot.io} etc) used \code{plot.cond} and
-#' \code{plot.uncond} to construct the conditional and unconditional detection
-#' functions respectively.  This is no longer the case although the advanced
-#' user can still call \code{plot.cond} and \code{plot.uncond} if required.  It
-#' is not intended for the user to call any of \code{plot.ds},
+#' It is not intended for the user to call any of \code{plot.ds},
 #' \code{plot.trial.fi}, \code{plot.trial},\code{plot.rem.fi}, \code{plot.rem},
 #' \code{plot.io.fi} or \code{plot.io} but the arguments are documented here.
 #' Instead the generic \code{plot} command should be used and it will call the
 #' appropriate function based on the type of \code{ddf} object.
 #' 
-#' For plot routine \code{plot.ds} the \code{which} command allows the user to
-#' select which plots are returned from the following options: \tabular{ll}{
-#' \code{which} \tab \code{plot}\cr \code{1} \tab data summary plot - a
-#' histogram of the observed distances \cr \code{2} \tab a scaled histogram of
-#' detections with a line giving the detection function averaged over the
-#' estimated population levels of the covariate values, and one dot for each
-#' observation at its estimated detection probability.\cr }
-#' 
-#' For plot routines \code{plot.trial.fi} and \code{plot.trial} the following
-#' plots are available: \tabular{ll}{ \code{which} \tab \code{plot} \cr
-#' \code{1} \tab data summary plot - a histogram of the observed distances for
-#' observer 1 \cr \code{2} \tab data summary plot - a histogram of the observed
-#' distances for observer 2 \cr \code{3} \tab Observer 1 detection function - a
-#' scaled histogram of detections with fitted DS model scaled from the MR
-#' estimated g(0).  The line shows the population average detection function
-#' and the points display estimated detection probability \cr \code{4} \tab
-#' Conditional MR detection function - observer 1 given obs 2, giving the
-#' proportion of duplicates with fitted MR model averaged over population
-#' covariate vales and dots for each estimated detection probability. \cr } For
-#' plot routines \code{plot.rem.fi} and \code{plot.rem} the following plots are
-#' available: \tabular{ll}{ \code{which} \tab \code{plot} \cr \code{1} \tab
-#' data summary plot - a histogram of the observed distances for observer 1 \cr
-#' \code{2} \tab data summary plot - a histogram of the observed distances for
-#' observer 2 \cr \code{3} \tab Observer 1 detection function - a scaled
-#' histogram of detections with fitted DS model scaled from the MR estimated
-#' g(0).  The line shows the population average detection function and the
-#' points display estimated detection probability \cr \code{4} \tab Conditional
-#' MR detection function - observer 1 given obs 2, giving the proportion of
-#' duplicates with fitted MR model averaged over population covariate vales and
-#' dots for each estimated detection probability. \cr }
-#' 
-#' For plot routines \code{plot.io.fi} and \code{plot.io} the following plots
-#' are available: \tabular{ll}{ \code{which} \tab \code{plot} \cr \code{1} \tab
-#' data summary plot - a histogram of the observed distances for observer 1 \cr
-#' \code{2} \tab data summary plot - a histogram of the observed distances for
-#' observer 2 \cr \code{3} \tab Observer 1 detection function - a scaled
-#' histogram of detections with fitted DS model scaled from the MR estimated
-#' g(0).  The line shows the population average detection function and the
-#' points display estimated detection probability \cr \code{4} \tab Observer 2
-#' detection function - as for \code{plot} 3 but using the detections from
-#' Observer 2\cr \code{5} \tab Duplicates detection function - as for
-#' \code{plot} 3 but using the duplicate detections\cr \code{6} \tab Pooled
-#' detection function - as for \code{plot} 3 but using the pooled detections\cr
-#' \code{7} \tab Conditional MR detection function - observer 1 given obs 2,
-#' giving the proportion of duplicates with fitted MR model averaged over
-#' population covariate vales and dots for each estimated detection
-#' probability. \cr \code{8} \tab Conditional MR detection function - observer
-#' 2 given obs 1, giving the proportion of duplicates with fitted MR model
-#' averaged over population covariate vales and dots for each estimated
-#' detection probability. \cr }
+#' The \code{which} command allows the user to
+#' select which plots are returned. See which argument definition. 
 #' 
 #' @aliases plot.ds
 #' @S3method plot ds
 #' @method plot ds
 #' @export
 #' @param x fitted model from \code{ddf}
-#' @param which index to specify which plots should be produced. See
-#'   \code{details.}
+#' @param which index to specify which plots should be produced. 1: histogram, 2: histogram with fitted line and points.
 #' @param byvar name of variable to be used to color points - not currently
 #'   implemented.
 #' @param breaks user define breakpoints
@@ -331,7 +279,7 @@ plot.ds <- function(x,which=c(2),byvar="",breaks=NULL,nc=NULL,winht=4,winwd=6,ji
 
   # Data summary plot for observer 1
   if(show[1]){
-    dev.new()
+	  if(.Device=="windows") dev.new()
     histline(h1$counts,breaks=breaks,lineonly=FALSE,ylim=c(0,ymax),xlab=xlab,ylab="Frequency",fill=TRUE,angle=angval1,density=denval1,col=byval1,...)
     title(paste(p1.name,"detections"),cex.main=0.8)
   }
@@ -339,7 +287,7 @@ plot.ds <- function(x,which=c(2),byvar="",breaks=NULL,nc=NULL,winht=4,winwd=6,ji
   # Detection function plot overlaid on historgram of observed 
   # distances - much of this code is taken from earlier plot.ds function.
   if(show[2]){
-	dev.new()
+	if(.Device=="windows") dev.new()
     # Primary detection function
     gxvalues <- detfct(xmat$distance,ddfobj,select=selected,width=width)
     ymax <- max(hist.obj$density,max(gxvalues))
